@@ -6,6 +6,7 @@ use serde::Deserialize;
 pub struct Config {
     pub shell: Option<String>,
     pub item: Option<Vec<ConfigItem>>,
+    pub items: Option<Vec<ConfigItem>>,
 }
 
 /// Structure for configuration apply items
@@ -23,8 +24,8 @@ pub struct ConfigItem {
 
 impl Config {
     /// Parse a TOML str into a Config struct
-    pub fn from_str(contents: &str) -> Result<Config> {
-        toml::from_str(&contents)
+    pub fn read(contents: &str) -> Result<Config> {
+        toml::from_str(contents)
             .context("Couldn't parse configuration file. Check if it's syntatically correct")
     }
 }
